/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for AnalyticsSnapshot.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AnalyticsSnapshot extends GenericJson {

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<StringCount> browsers;

  static {
    // hack to force ProGuard to consider StringCount used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(StringCount.class);
  }

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<StringCount> countries;

  static {
    // hack to force ProGuard to consider StringCount used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(StringCount.class);
  }

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long longUrlClicks;

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<StringCount> platforms;

  static {
    // hack to force ProGuard to consider StringCount used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(StringCount.class);
  }

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<StringCount> referrers;

  static {
    // hack to force ProGuard to consider StringCount used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(StringCount.class);
  }

  /**
   * Number of clicks on this short URL.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long shortUrlClicks;

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getBrowsers() {
    return browsers;
  }

  /**
   * Top browsers, e.g. "Chrome"; sorted by (descending) click counts. Only present if this data is
   * available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setBrowsers(java.util.List<StringCount> browsers) {
    this.browsers = browsers;
    return this;
  }

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getCountries() {
    return countries;
  }

  /**
   * Top countries (expressed as country codes), e.g. "US" or "DE"; sorted by (descending) click
   * counts. Only present if this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setCountries(java.util.List<StringCount> countries) {
    this.countries = countries;
    return this;
  }

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value returned may be {@code null}.
   */
  public Long getLongUrlClicks() {
    return longUrlClicks;
  }

  /**
   * Number of clicks on all goo.gl short URLs pointing to this long URL.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setLongUrlClicks(Long longUrlClicks) {
    this.longUrlClicks = longUrlClicks;
    return this;
  }

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getPlatforms() {
    return platforms;
  }

  /**
   * Top platforms or OSes, e.g. "Windows"; sorted by (descending) click counts. Only present if
   * this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setPlatforms(java.util.List<StringCount> platforms) {
    this.platforms = platforms;
    return this;
  }

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value returned may be {@code null}.
   */
  public java.util.List<StringCount> getReferrers() {
    return referrers;
  }

  /**
   * Top referring hosts, e.g. "www.google.com"; sorted by (descending) click counts. Only present
   * if this data is available.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setReferrers(java.util.List<StringCount> referrers) {
    this.referrers = referrers;
    return this;
  }

  /**
   * Number of clicks on this short URL.
   * The value returned may be {@code null}.
   */
  public Long getShortUrlClicks() {
    return shortUrlClicks;
  }

  /**
   * Number of clicks on this short URL.
   * The value set may be {@code null}.
   */
  public AnalyticsSnapshot setShortUrlClicks(Long shortUrlClicks) {
    this.shortUrlClicks = shortUrlClicks;
    return this;
  }

}
