/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Url.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Url extends GenericJson {

  /**
   * A summary of the click analytics for the short and long URL. Might not be present if not
   * requested or currently unavailable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AnalyticsSummary analytics;

  /**
   * Time the short URL was created; ISO 8601 representation using the yyyy-MM-dd'T'HH:mm:ss.SSSZZ
   * format, e.g. "2010-10-14T19:01:24.944+00:00".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String created;

  /**
   * Short URL, e.g. "http://goo.gl/l6MS".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The fixed string "urlshortener#url".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Long URL, e.g. "http://www.google.com/". Might not be present if the status is "REMOVED".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String longUrl;

  /**
   * Status of the target URL. Possible values: "OK", "MALWARE", "PHISHING", or "REMOVED". A URL
   * might be marked "REMOVED" if it was flagged as spam, for example.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * A summary of the click analytics for the short and long URL. Might not be present if not
   * requested or currently unavailable.
   * The value returned may be {@code null}.
   */
  public AnalyticsSummary getAnalytics() {
    return analytics;
  }

  /**
   * A summary of the click analytics for the short and long URL. Might not be present if not
   * requested or currently unavailable.
   * The value set may be {@code null}.
   */
  public Url setAnalytics(AnalyticsSummary analytics) {
    this.analytics = analytics;
    return this;
  }

  /**
   * Time the short URL was created; ISO 8601 representation using the yyyy-MM-dd'T'HH:mm:ss.SSSZZ
   * format, e.g. "2010-10-14T19:01:24.944+00:00".
   * The value returned may be {@code null}.
   */
  public String getCreated() {
    return created;
  }

  /**
   * Time the short URL was created; ISO 8601 representation using the yyyy-MM-dd'T'HH:mm:ss.SSSZZ
   * format, e.g. "2010-10-14T19:01:24.944+00:00".
   * The value set may be {@code null}.
   */
  public Url setCreated(String created) {
    this.created = created;
    return this;
  }

  /**
   * Short URL, e.g. "http://goo.gl/l6MS".
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Short URL, e.g. "http://goo.gl/l6MS".
   * The value set may be {@code null}.
   */
  public Url setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The fixed string "urlshortener#url".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The fixed string "urlshortener#url".
   * The value set may be {@code null}.
   */
  public Url setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Long URL, e.g. "http://www.google.com/". Might not be present if the status is "REMOVED".
   * The value returned may be {@code null}.
   */
  public String getLongUrl() {
    return longUrl;
  }

  /**
   * Long URL, e.g. "http://www.google.com/". Might not be present if the status is "REMOVED".
   * The value set may be {@code null}.
   */
  public Url setLongUrl(String longUrl) {
    this.longUrl = longUrl;
    return this;
  }

  /**
   * Status of the target URL. Possible values: "OK", "MALWARE", "PHISHING", or "REMOVED". A URL
   * might be marked "REMOVED" if it was flagged as spam, for example.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * Status of the target URL. Possible values: "OK", "MALWARE", "PHISHING", or "REMOVED". A URL
   * might be marked "REMOVED" if it was flagged as spam, for example.
   * The value set may be {@code null}.
   */
  public Url setStatus(String status) {
    this.status = status;
    return this;
  }

}
